function diffusionPlot(tracks, Dcoeffs, trackscolor)
%%DIFFUSIONPLOT Plot tracks colour coded by diffusion coefficient. 

h = figure(2);
x = Dcoeffs;

% Defining colour and range.
c_range = [0 max(Dcoeffs)]; % pick a range of values that should map to full color scale
cmap = colormap(trackscolor); % get colormap data
cmap_size = size(cmap,1); % get the number of rows in the colormap

% Turning diffusion coefficients into colourmap.
x_index = ceil( (x - c_range(1)) .* cmap_size ./ (c_range(2) - c_range(1)) ); % translate x values to colormap indices (i.e. % value of D convert to rgb)
x_index = max(x_index,1); x_index = min(x_index,cmap_size); % limit index array bounds
x_rgb = cmap(x_index,:);% read rgb values from colormap

    for i = 1:numel(tracks)
        Dcoeff = Dcoeffs(i,1);
        plot3(tracks{i,1}(:,2),tracks{i,1}(:,3),tracks{i,1}(:,4),'color',x_rgb(i,:),'linewidth', 1.5);
        hold on
    end
    

h = colorbar; set(h); h.Label.String = 'Diffusion Coefficient (µm^2 s^{-1})'; % toggle in colorbar

% correctly labelling colorbar
c_lim = round(max(x),1,'decimals'); c_ticks = [0:0.1:c_lim];
c_ticknum = numel(c_ticks)-1; c_interval = 1/c_ticknum;
h.YTick = [0:c_interval:1];

    for j=1:numel(c_ticks)
        lab = num2str(c_ticks(j));
        labs(j) = string(lab);
    end
    
h.YTickLabel = (labs);
axis equal
xlabel('x (\mum)'); ylabel('y (\mum)'); zlabel('z (\mum)');
view([45 45])

end
